@@ -16,16 +16,14 @@ c	(->	------------------------------------
                                    !    'skeleton'. Default is 'skeletonParam'.  This is the Namelist data
                                    !     referred by Cosmos automatically  if Job='flesh' is specified. For
                                    !     Job='flesh', you have to modify some part of  this file.
+        character*70  DpmFile      !2  control card to specify the dpmjet execution conditions. If ' ',
+	                           !   Cosmos/Data/DPM/atmos.inp is assumed.  
 	character*10  Job          !1  What kind of job you are going to do.\newline
                                    !   =' ' (default).  nothing special.\newline
-                                   !   ='skeleton'.  Makes skeleton. Later you can add AS, follow particles
-                                   !        to a lower energy and/or to a deeper depth, by giving Job='flesh'.
-                                   !        'skeletonParm' is automatically created.\newline
-                                   !   ='flesh'. Using information created by Job='skeleton' and the 
-                                   !             initial random number for each event, you can add AS,
-                                   !             follow particles to a lower energy and/or to a deeper depth.
-	                           !             The namelist parameters you give should be 'skeletonParam'
-	                           !             with some necessary modification.
+                                   !   ='skeleton'.  Makes skeleton. \newline
+                                   !   ='flesh'. Flesh skeleton events.  See manual.\newline
+                                   !   ='newskel'   \newline
+                                   !   ='newflesh'  see manual. \newline
         character*70  SeedFile     !1   File to  contain the initial random numbers for those events to 
                                    !    which you want to flesh. You can create the file by calling
                                    !     cwriteSeed in a user hook routine (say, in chookEnEvent) at 
@@ -34,7 +32,11 @@ c	(->	------------------------------------
                                    !      and the event number are  automatically output on the speicfied disk file.
         integer       SeedFileDev  !2   logical device number of SeedFile.
 	logical       Cont         !1  If T, continuation from a previous job is assumed. Contfile content is used.
-	integer       InitRN       !1  Initial random number seed. 2 integers.
+	integer       InitRN       !1  Initial random number seed. 2 integers. If InitRN(1) < 0, file dev #14 is
+                                   ! assumed to have  pairs of IR in each row, and they are read to initialize
+                                   ! each event.  This is not enabled when Job = 'flesh'. The #14 file should be
+                                   ! opened by the user routine   (chookBgRun). This is almost debug purpose.
+                                   ! If InitRn(2)<0, timer and host name are used for the initialization.
 	integer       EventNo      !2  cumulative event number counter.(excluding discarded ones due to cutoff).
 	integer       EventsInTheRun !2  Counter for event number in the run. Internal use.
                                      !          (excluding discarded ones due to cutoff).
@@ -71,7 +73,7 @@ c	<-)	-------------------------------------
      *  PrevEventNo, SeedFileDev, EventNo
 
 
-	common /Zmanagerpc2/ UserHookc(MAX_USERHOOKC), PrimaryFile,
-     *  CutOffFile,  Job, ContFile, AtmosFile, GeomagFile,
-     *  SkeletonFile, SeedFile, DeadLine
-
+       common /Zmanagerpc2/
+     * UserHookc(MAX_USERHOOKC), PrimaryFile,
+     * CutOffFile,  Job, ContFile, AtmosFile, GeomagFile,
+     * SkeletonFile, SeedFile, DpmFile, DeadLine
